@@ -10,7 +10,10 @@ from ..utils import misc as mx
 from sklearn.base import ClassifierMixin
 from ..optimizers import Optimizer
 from scipy.special import logsumexp, expit, erf
-
+try: 
+    import jax.numpy as jnp
+except ImportError:
+    pass
 
 class GLMClassifier(GLM, ClassifierMixin):
     """Generalized 'linear' models using quasi-randomized networks (classification)
@@ -73,6 +76,9 @@ class GLMClassifier(GLM, ClassifierMixin):
 
         optimizer: object
             optimizer, from class nnetsauce.Optimizer
+        
+        backend: str.
+            "cpu" or "gpu" or "tpu".
 
         seed: int
             reproducibility seed for nodes_sim=='uniform'
@@ -110,6 +116,7 @@ class GLMClassifier(GLM, ClassifierMixin):
         type_clust="kmeans",
         type_scaling=("std", "std", "std"),
         optimizer=Optimizer(),
+        backend="cpu",
         seed=123,
     ):
         super().__init__(
@@ -129,6 +136,7 @@ class GLMClassifier(GLM, ClassifierMixin):
             type_clust=type_clust,
             type_scaling=type_scaling,
             optimizer=optimizer,
+            backend=backend,
             seed=seed,
         )
 
@@ -239,7 +247,10 @@ class GLMClassifier(GLM, ClassifierMixin):
         Y = self.optimizer.one_hot_encode(output_y, self.n_classes)
 
         # initialization
-        beta_ = np.linalg.lstsq(scaled_Z, Y, rcond=None)[0]
+        if self.backend == "cpu":
+            beta_ = np.linalg.lstsq(scaled_Z, Y, rcond=None)[0]
+        else:
+            beta_ = jnp.linalg.lstsq(scaled_Z, Y, rcond=None)[0]
 
         # optimization
         # fit(self, loss_func, response, x0, **kwargs):
