@@ -1,11 +1,9 @@
 from .ridge2Classifier import Ridge2Classifier
 from .ridge2Regressor import Ridge2Regressor
 from .ridge2MultitaskClassifier import Ridge2MultitaskClassifier
-from .elasticNet2Regressor import ElasticNet2Regressor
 
 __all__ = [
     "Ridge2Classifier",
     "Ridge2Regressor",
     "Ridge2MultitaskClassifier",
-    "ElasticNet2Regressor",
 ]
