@@ -1,9 +1,12 @@
 import numpy as np
 import platform
 from numpy import linalg as la
-if platform.system() in ('Linux', 'Darwin'):
+
+try:
     import jax.numpy as jnp
     from jax.numpy import linalg as jla
+except ImportError:
+    pass
 
 # import .matrixops as mo
 from . import matrixops as mo
@@ -11,7 +14,6 @@ from . import matrixops as mo
 
 # computes beta_hat = (t(x)%*%x + lam*I)^{-1}%*%t(x)%*%y
 def beta_hat(x, y, lam=None, backend="cpu"):
-
     # assert on dimensions
     if lam is None:
         return mo.safe_sparse_dot(
@@ -31,7 +33,7 @@ def beta_hat(x, y, lam=None, backend="cpu"):
 def inv_penalized_cov(x, lam=None, backend="cpu"):
     # assert on dimensions
     sys_platform = platform.system()
-    if backend in ("gpu", "tpu") and (sys_platform in ('Linux', 'Darwin')):
+    if backend in ("gpu", "tpu") and (sys_platform in ("Linux", "Darwin")):
         if lam is None:
             return jla.inv(mo.crossprod(x=x, backend=backend))
         return jla.inv(
@@ -54,9 +56,7 @@ def beta_Sigma_hat(
     Sigma_hat_=None,
     backend="cpu",
 ):  # for prediction only (X_star is not None)
-
     if (X is not None) & (y is not None):  # fit
-
         if len(X.shape) == 1:
             X = X.reshape(-1, 1)
 
@@ -76,9 +76,7 @@ def beta_Sigma_hat(
         Cn = inv_penalized_cov(x=X, backend=backend)
 
         if return_cov == True:
-
             if X_star is None:
-
                 beta_hat_ = mo.safe_sparse_dot(
                     a=Cn,
                     b=mo.crossprod(x=X, y=y, backend=backend),
@@ -110,7 +108,6 @@ def beta_Sigma_hat(
                 }
 
             else:
-
                 if beta_hat_ is None:
                     beta_hat_ = mo.safe_sparse_dot(
                         a=Cn,
@@ -161,9 +158,7 @@ def beta_Sigma_hat(
                 }
 
         else:  # return_cov == False
-
             if X_star is None:
-
                 beta_hat_ = mo.safe_sparse_dot(
                     a=Cn,
                     b=mo.crossprod(x=X, y=y, backend=backend),
@@ -193,7 +188,6 @@ def beta_Sigma_hat(
                 }
 
             else:
-
                 if beta_hat_ is None:
                     beta_hat_ = beta_hat(X, y)
                     Sigma_hat_ = np.eye(X.shape[1]) - mo.safe_sparse_dot(
@@ -225,11 +219,9 @@ def beta_Sigma_hat(
                 }
 
     else:  # X is None | y is None  # predict
-
         assert (beta_hat_ is not None) & (X_star is not None)
 
         if return_cov == True:
-
             assert Sigma_hat_ is not None
 
             return {
@@ -250,7 +242,6 @@ def beta_Sigma_hat(
             }
 
         else:
-
             return {
                 "preds": mo.safe_sparse_dot(
                     a=X_star, b=beta_hat_, backend=backend
@@ -272,9 +263,7 @@ def beta_Sigma_hat_rvfl(
     Sigma_hat_=None,
     backend="cpu",
 ):  # for prediction only (X_star is not None)
-
     if (X is not None) & (y is not None):  # fit
-
         if len(X.shape) == 1:
             X = X.reshape(-1, 1)
 
@@ -291,14 +280,12 @@ def beta_Sigma_hat_rvfl(
                     x=np.ones(X_star.shape[0]), y=X_star, backend=backend
                 )
 
-        s2 = s ** 2
-        lambda_ = (sigma ** 2) / s2
+        s2 = s**2
+        lambda_ = (sigma**2) / s2
         Cn = inv_penalized_cov(X, lam=lambda_)
 
         if return_cov == True:
-
             if X_star is None:
-
                 beta_hat_ = mo.safe_sparse_dot(
                     a=Cn,
                     b=mo.crossprod(x=X, y=y, backend=backend),
@@ -334,7 +321,6 @@ def beta_Sigma_hat_rvfl(
                 }
 
             else:
-
                 if beta_hat_ is None:
                     beta_hat_ = mo.safe_sparse_dot(
                         a=Cn,
@@ -383,15 +369,13 @@ def beta_Sigma_hat_rvfl(
                                 ),
                                 backend=backend,
                             )
-                            + (sigma ** 2) * np.eye(X_star.shape[0])
+                            + (sigma**2) * np.eye(X_star.shape[0])
                         )
                     ),
                 }
 
         else:  # return_cov == False
-
             if X_star is None:
-
                 beta_hat_ = mo.safe_sparse_dot(
                     a=Cn,
                     b=mo.crossprod(x=X, y=y, backend=backend),
@@ -424,7 +408,6 @@ def beta_Sigma_hat_rvfl(
                 }
 
             else:
-
                 if beta_hat_ is None:
                     beta_hat_ = beta_hat(X, y, lam=lambda_, backend=backend)
                     Sigma_hat_ = s2 * (
@@ -459,11 +442,9 @@ def beta_Sigma_hat_rvfl(
                 }
 
     else:  # X is None | y is None  # predict
-
         assert (beta_hat_ is not None) & (X_star is not None)
 
         if return_cov == True:
-
             assert Sigma_hat_ is not None
 
             return {
@@ -477,13 +458,12 @@ def beta_Sigma_hat_rvfl(
                             ),
                             backend=backend,
                         )
-                        + (sigma ** 2) * np.eye(X_star.shape[0])
+                        + (sigma**2) * np.eye(X_star.shape[0])
                     )
                 ),
             }
 
         else:
-
             return {
                 "preds": mo.safe_sparse_dot(
                     a=X_star, b=beta_hat_, backend=backend
@@ -505,9 +485,7 @@ def beta_Sigma_hat_rvfl2(
     Sigma_hat_=None,
     backend="cpu",
 ):  # for prediction only (X_star is not None)
-
     if (X is not None) & (y is not None):
-
         if len(X.shape) == 1:
             X = X.reshape(-1, 1)
 
@@ -524,7 +502,6 @@ def beta_Sigma_hat_rvfl2(
                 X_star = X_star.reshape(-1, 1)
 
         if fit_intercept == True:
-
             X = mo.cbind(np.ones(n), X)
             Cn = (
                 la.inv(
@@ -533,7 +510,7 @@ def beta_Sigma_hat_rvfl2(
                         b=mo.crossprod(x=X, backend=backend),
                         backend="cpu",
                     )
-                    + (sigma ** 2) * np.eye(p + 1)
+                    + (sigma**2) * np.eye(p + 1)
                 )
                 if backend == "cpu"
                 else jla.inv(
@@ -542,7 +519,7 @@ def beta_Sigma_hat_rvfl2(
                         b=mo.crossprod(x=X, backend=backend),
                         backend=backend,
                     )
-                    + (sigma ** 2) * np.eye(p + 1)
+                    + (sigma**2) * np.eye(p + 1)
                 )
             )
 
@@ -559,7 +536,7 @@ def beta_Sigma_hat_rvfl2(
                         b=mo.crossprod(x=X, backend=backend),
                         backend="cpu",
                     )
-                    + (sigma ** 2) * np.eye(p)
+                    + (sigma**2) * np.eye(p)
                 )
                 if backend == "cpu"
                 else jla.inv(
@@ -568,7 +545,7 @@ def beta_Sigma_hat_rvfl2(
                         b=mo.crossprod(x=X, backend=backend),
                         backend=backend,
                     )
-                    + (sigma ** 2) * np.eye(p)
+                    + (sigma**2) * np.eye(p)
                 )
             )
 
@@ -581,9 +558,7 @@ def beta_Sigma_hat_rvfl2(
         y_hat = mo.safe_sparse_dot(a=smoothing_matrix, b=y, backend=backend)
 
         if return_cov == True:
-
             if X_star is None:
-
                 return {
                     "beta_hat": mo.safe_sparse_dot(
                         a=temp, b=y, backend=backend
@@ -601,7 +576,6 @@ def beta_Sigma_hat_rvfl2(
                 }
 
             else:
-
                 if beta_hat_ is None:
                     beta_hat_ = mo.safe_sparse_dot(a=temp, b=y, backend=backend)
 
@@ -631,15 +605,13 @@ def beta_Sigma_hat_rvfl2(
                                 ),
                                 backend=backend,
                             )
-                            + (sigma ** 2) * np.eye(X_star.shape[0])
+                            + (sigma**2) * np.eye(X_star.shape[0])
                         )
                     ),
                 }
 
         else:  # return_cov == False
-
             if X_star is None:
-
                 return {
                     "beta_hat": mo.safe_sparse_dot(
                         a=temp, b=y, backend=backend
@@ -651,7 +623,6 @@ def beta_Sigma_hat_rvfl2(
                 }
 
             else:
-
                 if beta_hat_ is None:
                     beta_hat_ = mo.safe_sparse_dot(a=temp, b=y, backend=backend)
 
@@ -667,11 +638,9 @@ def beta_Sigma_hat_rvfl2(
                 }
 
     else:  # (X is None) | (y is None) # predict
-
         assert (beta_hat_ is not None) & (X_star is not None)
 
         if return_cov == True:
-
             assert Sigma_hat_ is not None
 
             return {
@@ -687,13 +656,12 @@ def beta_Sigma_hat_rvfl2(
                             ),
                             backend=backend,
                         )
-                        + (sigma ** 2) * np.eye(X_star.shape[0])
+                        + (sigma**2) * np.eye(X_star.shape[0])
                     )
                 ),
             }
 
         else:
-
             return {
                 "preds": mo.safe_sparse_dot(
                     a=X_star, b=beta_hat_, backend=backend
